# $Id$
#
# common rules for linker invocation.
#
# Variables:
#
# srcdir      ... source directory.
# prefix      ... install prefix
# DESTDIR     ... temporary destination directory, where prefix resides. (Used by debian and rpm packagers)
# LD          ... path of linker (either CC or CXX), for BUILDTYPE=so,dll,exe or bin
# AR          ... path of ar, for BUILDTYPE=lib
# PKGCONFIG   ... path of the pkg-config tool.
# EXTPKGS     ... list of external pkg-config packages.
# OBJS        ... list of object files to link in, usually automatically created by common-compile.mk.
# LIBS        ... optional list of additional libraries
# SILENT_LIBS ... optional list of additional libraries, which are not propagated to pkg-config's .pc-file
# LDFLAGS     ... Additional linker flags
# BUILDTYPE   ... lib,so,dll,exe,bin
# ARTIFACT    ... The name of the build artifact
# ABI_VERSION ... Version of the ABI for shared libraries.
# NODEVRULES  ... If non-empty don't generate install-dev rules.
# LIBSUBDIR   ... subdirectory where executable should be installed. Will be set to
#                 $(ARCHLIBSUBDIR) or as a last fallback to 'lib' if empty.
#                 (Sometimes may be 'lib/foo' for installing into a subdirectory)
# BINSUBDIR   ... subdirectory where executable should be installed. Will be set to 'bin' if empty.
#                 (Sometimes may be 'sbin') 
#

ifeq ($(EXTPKGS),)
EXT_LIBS=
else
EXT_LIBS=$(shell $(PKGCONFIG) --libs $(EXTPKGS))
endif

ifeq ($(BUILDTYPE),dll)
include /usr/share/pba-cbs/mk/special-link-dll.mk
else ifeq ($(BUILDTYPE),so)
include /usr/share/pba-cbs/mk/special-link-so.mk
else ifeq ($(BUILDTYPE),lib)
include /usr/share/pba-cbs/mk/special-link-lib.mk
else ifeq ($(BUILDTYPE),exe)
include /usr/share/pba-cbs/mk/special-link-exe.mk
else ifeq ($(BUILDTYPE),bin)
include /usr/share/pba-cbs/mk/special-link-bin.mk
else
link::
	echo "Unsupported BUILDTYPE $(BUILDTYPE)." && exit 1
endif
